@@ -288,15 +288,17 @@ static interface_status_t detect_beat_auto(int fd, const char *iface)
 	}
 
 	try {
-		/* interface_status_t status = */ interface_detect_beat_wlan(fd, iface);
+		interface_status_t status = interface_detect_beat_wlan(fd, iface);
 		cached_detect_beat_func = interface_detect_beat_wlan;
+		return status;
 	} catch (MIIException& e) {
 		warning("Link beat detection (wlan) failed: %.*s\n", PFSTR(e.desc()));
 	}
 
 	try {
-		/* interface_status_t status = */ interface_detect_beat_priv(fd, iface);
+		interface_status_t status = interface_detect_beat_priv(fd, iface);
 		cached_detect_beat_func = interface_detect_beat_priv;
+		return status;
 	} catch (MIIException& e) {
 		warning("Link beat detection (priv) failed: %.*s\n", PFSTR(e.desc()));
 	}
@@ -424,7 +426,7 @@ void IFace::update() throw (IFaceException, MIIException)
 	
 			if (status == IFSTATUS_ERR)
 			{
-				_has_mii = false;
+				_has_mii = true;
 			} else {
 				_conn = status == IFSTATUS_UP;
 			}
