@@ -172,26 +172,32 @@ void IfaceParser::parse(FILE* input, ScanConsumer& sc)
 					map<string, string>::const_iterator ip = args.find("address");
 					map<string, string>::const_iterator mac = args.find("mac");
 					map<string, string>::const_iterator src = args.find("source");
+					
+					PeerScan* s = new PeerScan(profileName);
 
-					if (ip != args.end())
+					if (ip == args.end() && mac == args.end())
 					{
-						IPAddress ipAddr(ip->second);
+						warning("Missing IP or MAC address at line %d: skipping line\n", linenum);
+					} else {
+						if (ip != args.end())
+							s->setIP(IPAddress(ip->second));
 
-						struct ether_addr macAddr;
 						if (mac != args.end())
+						{
+							struct ether_addr macAddr;
 							parse_mac(&macAddr, mac->second);
-						else {
-							debug("Missing mac at line %d: only check for the IP\n", linenum);
-							bzero(&macAddr, sizeof(struct ether_addr));
-						}
+							s->setMAC(macAddr);
+						} else
+							warning("No mac provided at line %d: scans will be less accurate\n", linenum);
 
 						if (src != args.end())
-							sc.handleScan(new PeerScan(profileName, macAddr, ipAddr, IPAddress(src->second)));
-						else
-							sc.handleScan(new PeerScan(profileName, macAddr, ipAddr));
+							s->setSource(IPAddress(src->second));
+
+						if (ip == args.end() && mac != args.end() && src == args.end())
+							warning("Mac-only peer test is likely to fail unless you provide a source IP address");
+						
+						sc.handleScan(s);
 						found++;
-					} else {
-						warning("Missing address at line %d: skipping line\n", linenum);
 					}
 				}
 			}
