@@ -41,7 +41,7 @@ using namespace std;
 class NetWatcherImpl : public Thread
 {
 protected:
-	static const int captureSize = LIBNET_ETH_H + (LIBNET_ARP_H >? LIBNET_IPV4_H) + LIBNET_UDP_H + 300;
+	static const int captureSize = LIBNET_ETH_H + (LIBNET_ARP_H >? LIBNET_IPV4_H) + (LIBNET_UDP_H >? ICMP_ECHO) + 300;
 
 	int _ref;
 	string iface;
@@ -53,6 +53,7 @@ protected:
 	list<PacketListener*> listeners_arp;
 	list<PacketListener*> listeners_ethernet;
 	list<PacketListener*> listeners_dhcp;
+	list<PacketListener*> listeners_icmp;
 
 	struct libnet_link_int* link_interface;
 
@@ -102,6 +103,12 @@ public:
 		MutexLock lock(listenersMutex);
 		listeners_dhcp.push_back(pl);
 	}
+
+	void addICMPListener(PacketListener* pl) throw ()
+	{
+		MutexLock lock(listenersMutex);
+		listeners_icmp.push_back(pl);
+	}
 };
 
 /*
@@ -162,7 +169,7 @@ void* NetWatcherImpl::main() throw ()
 			}
 			else if (ntohs (packet_header->ether_type) == ETHERTYPE_IP)
 			{
-				if (!listeners_dhcp.empty())
+				if (!(listeners_dhcp.empty() || listeners_icmp.empty()))
 				{
 					// IPv4 packet
 					NetBuffer ipv4 = pkt.after(LIBNET_ETH_H);
@@ -196,6 +203,12 @@ memdump("IP: ", (unsigned char*)ipv4_header, (int)(ipv4_header->ip_hl*4) + LIBNE
 									i != listeners_dhcp.end(); i++)
 								(*i)->handleDHCP(dhcp);
 						}
+					} else if (ipv4_header->ip_p == IPPROTO_ICMP) {
+						// ICMP packet
+						NetBuffer icmp = ipv4.after(ipv4_header->ip_hl*4);
+						for (list<PacketListener*>::iterator i = listeners_icmp.begin();
+								i != listeners_icmp.end(); i++)
+							(*i)->handleICMP(icmp);
 					}
 				}
 			}
@@ -203,6 +216,7 @@ memdump("IP: ", (unsigned char*)ipv4_header, (int)(ipv4_header->ip_hl*4) + LIBNE
 	} catch (Exception& e) {
 		error("%s: %.*s.  Quitting NetWatcher thread.\n", e.type(), PFSTR(e.desc()));
 	}
+	return 0;
 }
 
 
