@@ -55,8 +55,10 @@ public:
 class PacketListener
 {
 public:
+	virtual ~PacketListener() {}
 	virtual void handleARP(const NetBuffer& pkt) throw () {}
 	virtual void handleDHCP(const NetBuffer& pkt) throw () {}
+	virtual void handleICMP(const NetBuffer& pkt) throw () {}
 	virtual void handleEthernet(const NetBuffer& pkt) throw () {}
 };
 
@@ -82,6 +84,7 @@ public:
 
 	void addARPListener(PacketListener* pl) throw ();
 	void addDHCPListener(PacketListener* pl) throw ();
+	void addICMPListener(PacketListener* pl) throw ();
 	void addEthernetListener(PacketListener* pl) throw ();
 
 	void shutdown() throw ();
