@@ -14,6 +14,8 @@ public:
 	PacketMaker(NetSender& sender) : sender(sender) {}
 	
 	Buffer makeARPRequest(const IPAddress& ip, const IPAddress& src) throw ();
+	Buffer makeARPRequest(const ether_addr& mac, const IPAddress& src) throw ();
+	Buffer makePingRequest(const ether_addr& mac, const IPAddress& src) throw ();
 	Buffer makeDHCPRequest() throw ();
 };
 
