@@ -31,6 +31,8 @@
 
 #include <list>
 
+class NetWatcher;
+
 class PeerScanner : public Scanner, public PacketListener
 {
 protected:
@@ -45,9 +47,12 @@ public:
 		: Scanner(listener), sender(sender) {}
 	virtual ~PeerScanner() throw () {}
 
+	virtual void handleEthernet(const NetBuffer& arp) throw ();
 	virtual void handleARP(const NetBuffer& arp) throw ();
 	
 	void addCandidate(const PeerScan* scan) throw ();
+
+	void registerWith(NetWatcher& watcher) throw ();
 };
 
 // vim:set ts=4 sw=4:
