@@ -39,6 +39,12 @@ using namespace stringf;
 //#define DEBUG(args...) fprintf(stderr, ##args)
 #define DEBUG(args...) do {} while(0)
 
+static bool canRun(const string& cmdline)
+{
+	size_t pos = cmdline.find(' ');
+	string file = pos == string::npos ? cmdline : cmdline.substr(0, pos);
+	return access(file.c_str(), X_OK) != -1;
+}
 
 class Script : public Process
 {
@@ -63,10 +69,20 @@ int Script::main() throw ()
 		runner.addEnv("NAME=" + tag);
 		runner.addEnv("IFACE=" + iface);
 		runner.addEnv("GUESSNET=true");
+		runner.addEnv(string("PATH=") + SCRIPTDIR + ":/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin");
 
 		runner.addArg("/bin/sh");
 		runner.addArg("-c");
-		runner.addArg(cmdline);
+
+		// Try to find the command in known locations
+		string cmd = cmdline;
+		if (cmdline[0] != '/')
+		{
+			cmd = string(SCRIPTDIR) + "/" + cmdline;
+		}
+		if (!canRun(cmd))
+			throw SystemException(errno, "checking if " + cmd + " can be executed");
+		runner.addArg(cmd);
 
 		DEBUG("SCRIPT MAIN Running %.*s\n", PFSTR(cmdline));
 
