@@ -32,7 +32,7 @@ void ScriptScanner::handleTermination(const std::string& signature, int status)
 
 	map<string, const Scan*>::iterator i = scans.find(signature);
 	if (i != scans.end())
-		found(i->second);
+		succeeded(i->second);
 }
 
 
