@@ -98,6 +98,8 @@ public:
 	const in_addr_t* s_addr_p() const throw () { return &(addr.s_addr); }
 
 	operator const struct in_addr*() const { return &addr; }
+	bool operator==(const IPAddress& addr) const;
+	bool operator!=(const IPAddress& addr) const;
 };
 
 /* Format an IPv4 address in a static char buffer */
